@@ -54,7 +54,8 @@ public Q_SLOTS:
 
 private:
     void appendEvent(int channel, short key, short velocity, unsigned int duration);
-    static void sequencerCallback(unsigned int time, fluid_event_t *event, fluid_sequencer_t *seq, void *data);
+    static void sequencerCallback(unsigned int time, fluid_event_t *event, fluid_sequencer_t *seq,
+                                  void *data);
     void resetEngine();
     void deleteEngine();
 
@@ -73,4 +74,3 @@ private:
 };
 
 #endif
-
